'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _assign = require('babel-runtime/core-js/object/assign');

var _assign2 = _interopRequireDefault(_assign);

exports.compile = compile;
exports.handlebars = handlebars;
exports.markdown = markdown;
exports.copy = copy;

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _fsExtra = require('fs-extra');

var _fsExtra2 = _interopRequireDefault(_fsExtra);

var _mkdirp = require('mkdirp');

var _handlebars = require('handlebars');

var _frontMatter = require('front-matter');

var _frontMatter2 = _interopRequireDefault(_frontMatter);

var _config = require('../lib/config');

var _config2 = _interopRequireDefault(_config);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function compile(paths, callback) {
  var ext = _path2.default.parse(paths.full).ext.split('.')[1];

  switch (ext) {
    case 'hbs':
    case 'handlebars':
      exports.handlebars(paths);
      break;
    case 'md':
    case 'markdown':
      exports.markdown(paths);
      break;
    default:
      exports.copy(paths);
  }

  if (typeof callback === 'function') {
    callback();
  }
}

function handlebars(paths) {
  var name = _path2.default.parse(paths.full).name;
  var subPath = paths.full.includes('/posts') ? 'posts/' : '';
  var folders = name === 'index' ? name : name + '/' + 'index';

  var output = _config2.default.outputDir + '/' + subPath + folders + '.html';
  var content = false;

  try {
    content = _fsExtra2.default.readFileSync(paths.full, 'utf8');
  } catch (err) {
    throw err;
  }

  var tags = {
    package: require(process.cwd() + '/package.json'),
    body: content
  };

  if (_frontMatter2.default.test(content)) {
    var parsed = (0, _frontMatter2.default)(content);

    tags.body = parsed.body;
    tags.page = parsed.attributes;
  }

  var layoutName = tags.page ? tags.page.layout || _config2.default.defaultLayout : _config2.default.defaultLayout;
  var layout = false;

  try {
    layout = _fsExtra2.default.readFileSync(process.cwd() + '/layouts/' + layoutName + '.hbs', 'utf8');
  } catch (err) {
    throw err;
  }

  (0, _assign2.default)(tags, _config2.default);

  var innerTags = {};
  (0, _assign2.default)(innerTags, tags);

  delete innerTags['body'];

  tags.body = (0, _handlebars.compile)(tags.body)(innerTags);
  var page = (0, _handlebars.compile)(layout)(tags);

  try {
    (0, _mkdirp.sync)(_path2.default.dirname(output));
    _fsExtra2.default.writeFileSync(output, page);
  } catch (err) {
    throw err;
  }
}

function markdown(paths) {
  var engine = require('markdown').markdown;

  var name = _path2.default.parse(paths.full).name;
  var output = _config2.default.outputDir + '/posts/' + name + '.html';
  var content = false;

  try {
    content = _fsExtra2.default.readFileSync(paths.full, 'utf8');
  } catch (err) {
    throw err;
  }

  if (_frontMatter2.default.test(content)) {
    var parsed = (0, _frontMatter2.default)(content);
    content = parsed.body;
  }

  var post = engine.toHTML(content);

  try {
    (0, _mkdirp.sync)(_path2.default.dirname(output));
    _fsExtra2.default.writeFileSync(output, post);
  } catch (err) {
    throw err;
  }

  paths.full = output;
  paths.relative = paths.full.replace(process.cwd() + '/dist', '');

  exports.handlebars(paths);
  _fsExtra2.default.unlinkSync(paths.full);
}

function copy(paths) {
  if (paths.full.includes('node_modules')) {
    return;
  }

  var file = _fsExtra2.default.createReadStream(paths.full);
  var targetPath = _config2.default.outputDir + paths.relative;

  (0, _mkdirp.sync)(_path2.default.dirname(targetPath));
  var target = _fsExtra2.default.createWriteStream(targetPath);

  file.pipe(target);

  target.on('error', function (err) {
    console.error(err);
  });
}